@@ -5,11 +5,10 @@ from .. import utils
 
 
 class ExecApiMixin(object):
-    @utils.minimum_version('1.15')
     @utils.check_resource('container')
     def exec_create(self, container, cmd, stdout=True, stderr=True,
                     stdin=False, tty=False, privileged=False, user='',
-                    environment=None):
+                    environment=None, workdir=None, detach_keys=None):
         """
         Sets up an exec instance in a running container.
 
@@ -26,6 +25,12 @@ class ExecApiMixin(object):
             environment (dict or list): A dictionary or a list of strings in
                 the following format ``["PASSWORD=xxx"]`` or
                 ``{"PASSWORD": "xxx"}``.
+            workdir (str): Path to working directory for this exec session
+            detach_keys (str): Override the key sequence for detaching
+                a container. Format is a single character `[a-Z]`
+                or `ctrl-<value>` where `<value>` is one of:
+                `a-z`, `@`, `^`, `[`, `,` or `_`.
+                ~/.docker/config.json is used by default.
 
         Returns:
             (dict): A dictionary with an exec ``Id`` key.
@@ -35,14 +40,6 @@ class ExecApiMixin(object):
                 If the server returns an error.
         """
 
-        if privileged and utils.version_lt(self._version, '1.19'):
-            raise errors.InvalidVersion(
-                'Privileged exec is not supported in API < 1.19'
-            )
-        if user and utils.version_lt(self._version, '1.19'):
-            raise errors.InvalidVersion(
-                'User-specific exec is not supported in API < 1.19'
-            )
         if environment is not None and utils.version_lt(self._version, '1.25'):
             raise errors.InvalidVersion(
                 'Setting environment for exec is not supported in API < 1.25'
@@ -66,11 +63,22 @@ class ExecApiMixin(object):
             'Env': environment,
         }
 
+        if workdir is not None:
+            if utils.version_lt(self._version, '1.35'):
+                raise errors.InvalidVersion(
+                    'workdir is not supported for API version < 1.35'
+                )
+            data['WorkingDir'] = workdir
+
+        if detach_keys:
+            data['detachKeys'] = detach_keys
+        elif 'detachKeys' in self._general_configs:
+            data['detachKeys'] = self._general_configs['detachKeys']
+
         url = self._url('/containers/{0}/exec', container)
         res = self._post_json(url, data=data)
         return self._result(res, True)
 
-    @utils.minimum_version('1.16')
     def exec_inspect(self, exec_id):
         """
         Return low-level information about an exec command.
@@ -90,7 +98,6 @@ class ExecApiMixin(object):
         res = self._get(self._url("/exec/{0}/json", exec_id))
         return self._result(res, True)
 
-    @utils.minimum_version('1.15')
     def exec_resize(self, exec_id, height=None, width=None):
         """
         Resize the tty session used by the specified exec command.
@@ -109,7 +116,6 @@ class ExecApiMixin(object):
         res = self._post(url, params=params)
         self._raise_for_status(res)
 
-    @utils.minimum_version('1.15')
     @utils.check_resource('exec_id')
     def exec_start(self, exec_id, detach=False, tty=False, stream=False,
                    socket=False):
